@@ -15,7 +15,7 @@ package MBX::Alien::FLTK::Platform::Unix::Darwin;
         my ($self) = @_;
         $self->SUPER::configure(qw[no_gl no_x11])
             || return 0;    # Get basic config data
-        print "Gathering Solaris specific configuration data...\n";
+        print "Gathering Mac OSX specific configuration data...\n";
 
         # Asssumed true since this is *nix
         print "have pthread... yes (assumed)\n";
@@ -52,6 +52,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Darwin.pm 4944114 2009-11-02 19:12:59Z sanko@cpan.org $
+=for git $Id: Darwin.pm f70fb16 2009-11-02 19:42:51Z sanko@cpan.org $
 
 =cut
